.. EP-BOLFI documentation master file, created by
   sphinx-quickstart on Fri Nov 15 17:48:42 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

EP-BOLFI documentation
======================


.. toctree::

   readme
   api
   contributing

